@@ -171,6 +171,8 @@ class GroupedMessage(MessageBase):
         obj_request = message.request
 
         subject = 'Error (%s IP): %s' % ((obj_request.META.get('REMOTE_ADDR') in settings.INTERNAL_IPS and 'internal' or 'EXTERNAL'), obj_request.path)
+        if message.site:
+            subject  = '[%s] %s' % (message.site, subject)
         try:
             request_repr = repr(obj_request)
         except:
@@ -189,7 +191,7 @@ class GroupedMessage(MessageBase):
             'link': link,
         })
         
-        send_mail(settings.EMAIL_SUBJECT_PREFIX + subject, body,
+        send_mail(subject, body,
                   settings.SERVER_EMAIL, conf.ADMINS,
                   fail_silently=fail_silently)
     
@@ -300,4 +302,4 @@ register_indexes()
 
 # XXX: Django sucks and we can't listen to our specific app
 # post_syncdb.connect(GroupedMessage.create_sort_index, sender=__name__)
-post_syncdb.connect(GroupedMessage.create_sort_index, sender=sys.modules[__name__])
\ No newline at end of file
+post_syncdb.connect(GroupedMessage.create_sort_index, sender=sys.modules[__name__])
